@@ -2,7 +2,7 @@
 //  BWW to MusicXML converter
 //  Part of MusE Score
 //  Linux Music Score Editor
-//  $Id: symbols.h 3793 2010-12-22 21:54:17Z lvinken $
+//  $Id: symbols.h 4867 2011-10-16 19:25:05Z lvinken $
 //
 //  Copyright (C) 2010 Werner Schweer and others
 //
@@ -44,16 +44,7 @@ namespace Bww {
     TIE,
     TRIPLET,
     DOT,
-    SINGLEGRACE,
-    STRIKE,
-    DOUBLING,
-    HALFDOUBLING,
-    THUMBDOUBLING,
-    SLUR,
-    THROW,
-    BIRL,
-    GRIP,
-    TAORLUATH,
+    GRACE,
     UNKNOWN,
     NONE
   };
