@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: accidental.cpp 3923 2011-01-19 14:54:58Z wschweer $
+//  $Id: accidental.cpp 4502 2011-07-09 15:43:32Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -65,7 +65,9 @@ Acc accList[] = {
       Acc("flat arrow both",     QT_TRANSLATE_NOOP("accidental", "flat arrow both"),     0, 0, flatArrowBothSym),
       Acc("natural arrow up",    QT_TRANSLATE_NOOP("accidental", "natural arrow up"),    0, 0, naturalArrowUpSym),
       Acc("natural arrow down",  QT_TRANSLATE_NOOP("accidental", "natural arrow down"),  0, 0, naturalArrowDownSym),
-      Acc("natural arrow both",  QT_TRANSLATE_NOOP("accidental", "natural arrow both"),  0, 0, naturalArrowBothSym)
+      Acc("natural arrow both",  QT_TRANSLATE_NOOP("accidental", "natural arrow both"),  0, 0, naturalArrowBothSym),
+      Acc("sori",                QT_TRANSLATE_NOOP("accidental", "sori"),                0, 0, soriSym),
+      Acc("koron",               QT_TRANSLATE_NOOP("accidental", "koron"),               0, 0, koronSym)
       };
 
 //---------------------------------------------------------
@@ -364,6 +366,12 @@ void Accidental::read(QDomElement e)
                               case 34:
                                     i = ACC_NATURAL_ARROW_BOTH;
                                     break;
+                               case 35:
+                                    i = ACC_SORI;
+                                    break;
+                               case 36:
+                                    i = ACC_KORON;
+                                    break;                                                                        
                               default:
                                     i = 0;
                                     break;
