@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: accidental.h 3923 2011-01-19 14:54:58Z wschweer $
+//  $Id: accidental.h 4502 2011-07-09 15:43:32Z lasconic $
 //
 //  Copyright (C) 2004-2009 Werner Schweer and others
 //
@@ -60,6 +60,8 @@ enum AccidentalType {
       ACC_NATURAL_ARROW_UP,
       ACC_NATURAL_ARROW_DOWN,
       ACC_NATURAL_ARROW_BOTH,
+      ACC_SORI,
+      ACC_KORON,
       ACC_END
       };
 
