@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: actions.cpp 5000 2011-11-17 11:54:40Z lasconic $
+//  $Id: actions.cpp 5683 2013-02-18 15:30:04Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -1270,7 +1270,7 @@ Shortcut MuseScore::sc[] = {
          STATE_NORMAL | STATE_NOTE_ENTRY,
          "voice-1",
          QT_TRANSLATE_NOOP("action","voice 1"),
-         QKeySequence(Qt::CTRL+Qt::Key_I, Qt::CTRL+Qt::Key_1),
+         Qt::ALT+Qt::CTRL+Qt::Key_1,
          Qt::WindowShortcut,
          QT_TRANSLATE_NOOP("action","voice 1"),
          QT_TRANSLATE_NOOP("action","voice 1"),
@@ -1280,7 +1280,7 @@ Shortcut MuseScore::sc[] = {
          STATE_NORMAL | STATE_NOTE_ENTRY,
          "voice-2",
          QT_TRANSLATE_NOOP("action","voice 2"),
-         QKeySequence(Qt::CTRL+Qt::Key_I, Qt::CTRL+Qt::Key_2),
+         Qt::ALT+Qt::CTRL+Qt::Key_2,
          Qt::WindowShortcut,
          QT_TRANSLATE_NOOP("action","voice 2"),
          QT_TRANSLATE_NOOP("action","voice 2"),
@@ -1290,7 +1290,7 @@ Shortcut MuseScore::sc[] = {
          STATE_NORMAL | STATE_NOTE_ENTRY,
          "voice-3",
          QT_TRANSLATE_NOOP("action","voice 3"),
-         QKeySequence(Qt::CTRL+Qt::Key_I, Qt::CTRL+Qt::Key_3),
+         Qt::ALT+Qt::CTRL+Qt::Key_3,
          Qt::WindowShortcut,
          QT_TRANSLATE_NOOP("action","voice 3"),
          QT_TRANSLATE_NOOP("action","voice 3"),
@@ -1300,7 +1300,7 @@ Shortcut MuseScore::sc[] = {
          STATE_NORMAL | STATE_NOTE_ENTRY,
          "voice-4",
          QT_TRANSLATE_NOOP("action","voice 4"),
-         QKeySequence(Qt::CTRL+Qt::Key_I, Qt::CTRL+Qt::Key_4),
+         Qt::ALT+Qt::CTRL+Qt::Key_4,
          Qt::WindowShortcut,
          QT_TRANSLATE_NOOP("action","voice 4"),
          QT_TRANSLATE_NOOP("action","voice 4"),
