@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: beam.cpp 3500 2010-09-23 15:23:36Z lasconic $
+//  $Id: beam.cpp 4840 2011-10-05 08:24:10Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -285,8 +285,8 @@ void Beam::remove(ChordRest* a)
 
 void Beam::draw(QPainter& p) const
       {
+      p.setBrush(p.pen().color());
       p.setPen(QPen(Qt::NoPen));
-      p.setBrush(selected() ? preferences.selectColor[0] : preferences.defaultColor);
       for (ciBeamSegment ibs = beamSegments.begin();
          ibs != beamSegments.end(); ++ibs) {
             BeamSegment* bs = *ibs;
@@ -786,7 +786,7 @@ void Beam::layout()
 
             double x2 = npos.x();
             double y1 = npos.y();
-            double y  = _up ? qMin(qreal(p1dy), _p1[idx].y()) : qMax(p1dy, _p1[idx].y());
+            double y  = _up ? qMin(qreal(p1dy), _p1[idx].y()) : qMax(qreal(p1dy), _p1[idx].y());
             double y2 = y + (x2 - x1) * slope + cp.y();
 
             double stemLen = _up ? (y1 - y2) : (y2 - y1);
