@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: box.cpp 3077 2010-05-14 11:48:04Z wschweer $
+//  $Id: box.cpp 5317 2012-02-13 14:42:03Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -383,12 +383,13 @@ void HBox::propertyAction(ScoreView* viewer, const QString& cmd)
             vp.exec();
             }
       else if (cmd == "frame-text") {
-            Text* s = new Text(score());
-            s->setSubtype(TEXT_FRAME);
-            s->setParent(this);
-            score()->undoAddElement(s);
-            score()->select(s, SELECT_SINGLE, 0);
-            viewer->startEdit(s);
+            Text* t = new Text(score());
+            t->setSubtype(TEXT_FRAME);
+            t->setTextStyle(TEXT_STYLE_FRAME);
+            t->setParent(this);
+            score()->undoAddElement(t);
+            score()->select(t, SELECT_SINGLE, 0);
+            viewer->startEdit(t);
             score()->setLayoutAll(true);
             }
       }
@@ -436,6 +437,10 @@ bool VBox::genPropertyMenu(QMenu* popup) const
       a = getAction("poet-text");
       a->blockSignals(true);
       textMenu->addAction(a);
+      
+      a = getAction("frame-text");
+      a->blockSignals(true);
+      textMenu->addAction(a);
 
       a = getAction("insert-hbox");
       a->blockSignals(true);
@@ -482,6 +487,12 @@ void VBox::propertyAction(ScoreView* viewer, const QString& cmd)
             t->setTextStyle(TEXT_STYLE_POET);
             s = t;
             }
+      else if (cmd == "frame-text") {
+            Text* t = new Text(score());
+            t->setSubtype(TEXT_FRAME);
+            t->setTextStyle(TEXT_STYLE_FRAME);
+            s = t;
+            }
       else if (cmd == "insert-hbox") {
             s = new HBox(score());
             double w = width() - leftMargin() * DPMM - rightMargin() * DPMM;
