@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: capella.h 1840 2009-05-20 11:57:51Z wschweer $
+//  $Id: capella.h 5434 2012-03-08 14:03:15Z lasconic $
 //
 //  Copyright (C) 2009 Werner Schweer and others
 //
@@ -480,7 +480,7 @@ class WedgeObj : public LineObj {
 //---------------------------------------------------------
 
 class BasicDurationalObj : public CapellaObj {
-   protected:
+   public:
       int nDots;
       bool noDuration;
       bool postGrace;
@@ -493,7 +493,7 @@ class BasicDurationalObj : public CapellaObj {
       bool tripartite;
       bool isProlonging;
 
-   public:
+
       BasicDurationalObj(Capella* c) : CapellaObj(c) {}
       void read();
       int ticks() const;
@@ -614,10 +614,9 @@ class Capella {
       unsigned btmPageMargins;
 
       QList<QFont> fonts;
-      QList<CapStaffLayout*> staves;      // staff layout
+      QList<CapStaffLayout*> _staves;      // staff layout
+
 
-      int smallLineDist;            // layout
-      int normalLineDist;
       int topDist;
       int interDist;
       unsigned char txtAlign;       // Stimmenbezeichnungen 0=links, 1=zentriert, 2=rechts
@@ -664,6 +663,11 @@ class Capella {
       QList<CapSystem*> systems;
       QList<CapBracket> brackets;
       ChordObj* backgroundChord;
+      CapStaffLayout* staff(int idx)               { return _staves[idx]; }
+      const QList<CapStaffLayout*>& staves() const { return _staves; }
+      
+      double smallLineDist;            // layout
+      double normalLineDist;
       };
 
 #endif
