@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: chord.cpp 4902 2011-10-26 18:01:51Z wschweer $
+//  $Id: chord.cpp 5695 2013-02-20 12:48:24Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -1334,8 +1334,7 @@ void Chord::layout()
       //  process ledger lines
       //-----------------------------------------
 
-      foreach(const LedgerLine* l, _ledgerLines)
-            delete l;
+      qDeleteAll(_ledgerLines);
       _ledgerLines.clear();
 
       //---------------------------------------------------
