@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: chord.h 3769 2010-12-15 18:28:07Z lasconic $
+//  $Id: chord.h 4902 2011-10-26 18:01:51Z wschweer $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -140,7 +140,7 @@ class Chord : public ChordRest {
       virtual qreal upPos()   const;
       virtual qreal downPos() const;
       virtual qreal centerX() const;
-      void addLedgerLine(double x, int staffIdx, int line, int extend);
+      void addLedgerLine(double x, int staffIdx, int line, int extend, bool visible);
       void addLedgerLines(double x, int move);
 
    public:
@@ -154,7 +154,7 @@ class Chord : public ChordRest {
 
       void write(Xml& xml, int start, int end) const;
       virtual void write(Xml& xml) const { write(xml, 0, 0); }
-      void read(QDomElement, const QList<Tuplet*>&);
+      void read(QDomElement, QList<Tuplet*>&, Measure*);
       virtual void read(QDomElement);
       virtual void setSelected(bool f);
       virtual void dump() const;
@@ -196,7 +196,7 @@ class Chord : public ChordRest {
       virtual int upLine() const;
       virtual int downLine() const;
       virtual Space space() const;
-      void readNote(QDomElement node, const QList<Tuplet*>&);
+      void readNote(QDomElement node, QList<Tuplet*>&, Measure*);
 
       NoteType noteType() const         { return _noteType; }
       void setNoteType(NoteType t)      { _noteType = t; }
