@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: chordrest.cpp 3915 2011-01-18 13:47:34Z wschweer $
+//  $Id: chordrest.cpp 5668 2012-10-18 10:34:18Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -221,7 +221,7 @@ void ChordRest::writeProperties(Xml& xml) const
 //   readProperties
 //---------------------------------------------------------
 
-bool ChordRest::readProperties(QDomElement e, const QList<Tuplet*>& tuplets)
+bool ChordRest::readProperties(QDomElement e, QList<Tuplet*>& tuplets, Measure* measure)
       {
       if (Element::readProperties(e))
             return true;
@@ -260,8 +260,24 @@ bool ChordRest::readProperties(QDomElement e, const QList<Tuplet*>& tuplets)
                         break;
                         }
                   }
-            if (tuplet() == 0)
+            if (tuplet() == 0) {
                   printf("Tuplet id %d not found\n", i);
+                  // HACK: collect all tuplets and search again
+                  score()->collectTuplets(e, &tuplets);
+                  foreach(Tuplet* t, tuplets) {
+                        if (t->id() == i) {
+                              measure->add(t);
+                              setTuplet(t);
+                              break;
+                              }
+                        }
+                  }
+            // DEBUG:
+            if (measure && tuplet() && tuplet()->measure() != measure) {
+                  if (tuplet()->measure())
+                        tuplet()->measure()->remove(tuplet());
+                  measure->add(tuplet());
+                  }
             }
       else if (tag == "leadingSpace")
             _extraLeadingSpace = Spatium(val.toDouble());
@@ -342,9 +358,6 @@ void ChordRest::layoutArticulations()
       if (parent() == 0)
             return;
       double _spatium  = spatium();
-      Measure* m       = measure();
-      System* s        = m->system();
-      int idx          = staff()->rstaff() + staffMove();   // DEBUG
 
       qreal x          = centerX();
 
@@ -366,6 +379,10 @@ void ChordRest::layoutArticulations()
       //
 
       foreach (Articulation* a, articulations) {
+            
+            // copy articulation mag value from the chordrest
+            a->setMag(mag());
+            
             ArticulationAnchor aa = a->anchor();
             if (aa != A_CHORD && aa != A_TOP_CHORD && aa != A_BOTTOM_CHORD)
                   continue;
@@ -495,7 +512,7 @@ void ChordRest::removeSlurBack(Slur* s)
 //   drop
 //---------------------------------------------------------
 
-Element* ChordRest::drop(ScoreView* view, const QPointF& p1, const QPointF& p2, Element* e)
+Element* ChordRest::drop(ScoreView* view, const QPointF& p1, const QPointF& p2, Element* e, Fraction duration)
       {
       Measure* m  = measure();
       switch (e->type()) {
@@ -564,7 +581,7 @@ Element* ChordRest::drop(ScoreView* view, const QPointF& p1, const QPointF& p2,
                   {
                   Note* note = static_cast<Note*>(e);
                   score()->setNoteRest(this, track(), note->pitch(),
-                     Fraction(1, 4), note->headGroup(), AUTO);
+                     duration, note->headGroup(), AUTO);
                   delete e;
                   }
                   break;
