@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: edit.cpp 4574 2011-07-22 15:12:19Z lasconic $
+//  $Id: edit.cpp 5679 2013-02-18 14:12:54Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -273,7 +273,9 @@ Rest* Score::setRest(int tick, int track, Fraction l, bool useDots, Tuplet* tupl
             if (ev.nominalEqualActual()   // not in pickup measure
                && (measure->tick() == tick)
                && (measure->fraction() == f)
-               && (f < Duration(Duration::V_BREVE).fraction())) {
+/*  removed to have measures >= 2/1 emptied to V_MEASURE instead of actual rest value
+               && (f < Duration(Duration::V_BREVE).fraction()) */
+                        ) {
                   Rest* rest = addRest(tick, track, Duration(Duration::V_MEASURE), tuplet);
                   tick += rest->ticks();
                   if (r == 0)
@@ -467,7 +469,7 @@ void Score::changeTimeSig(int tick, int timeSigSubtype)
       Fraction ofraction(_sigmap->timesig(tick).fraction());
       Fraction nfraction(TimeSig::getSig(timeSigSubtype));
 
-      if (ofraction == nfraction) {
+      if ((ofraction.numerator() == nfraction.numerator()) && (ofraction.denominator() == nfraction.denominator())) {
             //
             // check if there is already a time signature symbol
             //
@@ -566,7 +568,7 @@ void Score::cmdRemoveTimeSig(TimeSig* ts)
       {
       if (ts->tick() == 0) {    // cannot remove time signature at tick 0
             QMessageBox::information(0,
-               tr("MuseScore"),
+               "MuseScore",
                tr("The first time signature of a piece can not be removed.")
                );
             return;
@@ -1851,8 +1853,11 @@ void ScoreView::changeVoice(int voice)
       //
       if (!is->noteEntryMode || is->cr())
             return;
-
-      is->_segment = is->_segment->measure()->firstCRSegment();
+            
+      if(is->_segment)
+            is->_segment = is->_segment->measure()->firstCRSegment();
+      else
+            is->_segment = score()->firstMeasure()->firstCRSegment();
       moveCursor();
       score()->setUpdateAll(true);
       score()->end();
