@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: editstaff.cpp 3865 2011-01-10 15:45:16Z lasconic $
+//  $Id: editstaff.cpp 4363 2011-06-11 13:52:24Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -61,6 +61,14 @@ EditStaff::EditStaff(Staff* s, QWidget* parent)
       pPitchMin->setValue(instrument.minPitchP());
       pPitchMax->setValue(instrument.maxPitchP());
 
+      Score* score  = staff->score();
+      TextStyle* ts = score->textStyle(TEXT_STYLE_INSTRUMENT_SHORT);
+      shortName->setCurrentFont(ts->font(score->spatium()));
+      shortName->document()->setDefaultFont(ts->font(score->spatium()));
+      ts = score->textStyle(TEXT_STYLE_INSTRUMENT_LONG);
+      longName->setCurrentFont(ts->font(score->spatium()));
+      longName->document()->setDefaultFont(ts->font(score->spatium()));
+
       connect(buttonBox, SIGNAL(clicked(QAbstractButton*)), this, SLOT(bboxClicked(QAbstractButton*)));
       connect(editDrumset, SIGNAL(clicked()), SLOT(editDrumsetClicked()));
       connect(changeInstrument, SIGNAL(clicked()), SLOT(showInstrumentDialog()));
@@ -202,10 +210,12 @@ void EditStaff::showInstrumentDialog()
             longName->setHtml(t->longName);
             
             Score* score  = staff->score();
-            TextStyle* s = score->textStyle(TEXT_STYLE_INSTRUMENT_SHORT);
-            shortName->document()->setDefaultFont(s->font(score->spatium()));
-            s = score->textStyle(TEXT_STYLE_INSTRUMENT_LONG);
-            longName->document()->setDefaultFont(s->font(score->spatium()));
+            TextStyle* ts = score->textStyle(TEXT_STYLE_INSTRUMENT_SHORT);
+            shortName->setCurrentFont(ts->font(score->spatium()));
+            shortName->document()->setDefaultFont(ts->font(score->spatium()));
+            ts = score->textStyle(TEXT_STYLE_INSTRUMENT_LONG);
+            longName->setCurrentFont(ts->font(score->spatium()));
+            longName->document()->setDefaultFont(ts->font(score->spatium()));
             
             instrument.setTrackName(t->trackName);
 
