@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: element.cpp 4362 2011-06-11 13:04:43Z lasconic $
+//  $Id: element.cpp 5453 2012-03-12 09:19:20Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -452,8 +452,10 @@ QList<Prop> Element::properties(Xml& xml, const Element* proto) const
             if (!s.isEmpty())
                   pl.append(Prop("subtype", subtypeName()));
             }
-      if (!_userOff.isNull())
+      if (!_userOff.isNull()) {
             pl.append(Prop("offset", _userOff / spatium()));
+            pl.append(Prop("pos", pos() / spatium())); // for upward compatibility
+            }
       if ((track() != xml.curTrack) && (track() != -1)) {
             int t;
             t = track() + xml.trackDiff;
@@ -518,6 +520,9 @@ bool Element::readProperties(QDomElement e)
             if (_systemFlag)
                   _track = 0;
             }
+      else if (tag == "pos") {
+      
+      }
       else
             return false;
       return true;
@@ -785,15 +790,16 @@ double StaffLines::y2() const
             return 0.0;
 
       double _spatium = spatium();
-      double y = system->staff(staffIdx())->y();
+      double y = system->staff(staffIdx())->y() + _pos.y();
       switch(lines()) {
             case 1:
-                  return y + _pos.y() + 3 * _spatium;
+                  return y  + 3 * _spatium;
             case 2:
-                  return y + _pos.y() + 3 * _spatium;
+                  return y  + 3 * _spatium;
             case 3:
+                  return y  + 4 * _spatium;
             default:
-                  return y + _pos.y() + 4 * _spatium;
+                  return y  + (lines() - 1) * _spatium;
             }
       }
 
@@ -943,6 +949,14 @@ Compound::Compound(Score* s)
       {
       }
 
+Compound::Compound(const Compound& c)
+   : Element(c)
+      {
+      elemente.clear();
+      foreach(Element* e, c.elemente)
+            elemente.append(e->clone());
+      }
+
 //---------------------------------------------------------
 //   draw
 //---------------------------------------------------------
@@ -1122,10 +1136,13 @@ void RubberBand::draw(QPainter& p) const
 
 QByteArray Element::mimeData(const QPointF& dragOffset) const
       {
-      QBuffer buffer;
+    const Element *e = this;
+    QBuffer buffer;
       buffer.open(QIODevice::WriteOnly);
       Xml xml(&buffer);
       xml.stag("Element");
+      if (e->type() == NOTE)
+            xml.fTag("duration", static_cast<const Note*>(e)->chord()->fraction());
       if (!dragOffset.isNull())
             xml.tag("dragOffset", dragOffset);
       write(xml);
@@ -1139,13 +1156,15 @@ QByteArray Element::mimeData(const QPointF& dragOffset) const
 //    return -1 if no valid type found
 //---------------------------------------------------------
 
-ElementType Element::readType(QDomElement& e, QPointF* dragOffset)
+ElementType Element::readType(QDomElement& e, QPointF* dragOffset, Fraction * duration)
       {
       ElementType type = INVALID;
 
       for (e = e.firstChildElement(); !e.isNull(); e = e.nextSiblingElement()) {
             if (e.tagName() == "dragOffset")
                   *dragOffset = readPoint(e);
+            else if (e.tagName() == "duration")
+                  *duration = readFraction(e);
             else if ((type = name2type(e.tagName())) == INVALID) {
                   domError(e);
                   break;
