@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: element.h 3707 2010-11-14 14:36:12Z lasconic $
+//  $Id: element.h 5453 2012-03-12 09:19:20Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -22,6 +22,7 @@
 #define __ELEMENT_H__
 
 #include "xml.h"
+#include "al/fraction.h"
 #include "globals.h"
 
 /**
@@ -282,7 +283,7 @@ class Element {
       QColor color() const            { return _color; }
       QColor curColor() const;
       void setColor(const QColor& c)  { _color = c;    }
-      static ElementType readType(QDomElement& node, QPointF*);
+      static ElementType readType(QDomElement& node, QPointF*, Fraction* duration);
 
       virtual QByteArray mimeData(const QPointF&) const;
 /**
@@ -301,6 +302,7 @@ class Element {
  Reimplemented by elements that accept drops.
 */
       virtual Element* drop(ScoreView*, const QPointF&, const QPointF&, Element*) { return 0;}
+      virtual Element* drop(ScoreView*, const QPointF&, const QPointF&, Element*, Fraction) { return 0;}
 
 /**
  Return a name for a \a subtype. Used for outputting xml data.
@@ -516,6 +518,7 @@ class Compound : public Element {
 
    public:
       Compound(Score*);
+      Compound(const Compound&);
       virtual ElementType type() const = 0;
 
       virtual void draw(QPainter&) const;
