@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: exportmidi.cpp 3269 2010-07-09 20:20:39Z lasconic $
+//  $Id: exportmidi.cpp 5349 2012-02-20 22:00:05Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -191,6 +191,7 @@ void ExportMidi::writeHeader()
       //--------------------------------------------
 
       AL::TempoMap* tempomap = cs->tempomap();
+      int relTempo = tempomap->relTempo();
       foreach(const RepeatSegment* rs, *cs->repeatList()) {
             int startTick  = rs->tick;
             int endTick    = startTick + rs->len;
@@ -204,7 +205,7 @@ void ExportMidi::writeHeader()
                   //
                   // compute midi tempo: microseconds / quarter note
                   //
-                  int tempo = lrint((1.0 / it->second.tempo) * 1000000.0);
+                  int tempo = lrint((1.0 / (it->second.tempo * relTempo * 0.01)) * 1000000.0);
 
                   ev->setMetaType(META_TEMPO);
                   ev->setLen(3);
