@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: file.cpp 4466 2011-07-03 20:34:25Z lasconic $
+//  $Id: file.cpp 5675 2013-02-16 12:06:16Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -73,6 +73,30 @@
 #include "scoretab.h"
 #include "beam.h"
 
+//---------------------------------------------------------
+//   createDefaultFileName
+//---------------------------------------------------------
+
+static QString createDefaultFileName(QString fn)
+      {
+      //
+      // special characters in filenames are a constant source
+      // of trouble, this replaces some of them common in german:
+      //
+      fn = fn.simplified();
+      fn = fn.replace(QChar(' '),  "_");
+      fn = fn.replace(QChar('\n'), "_");
+      fn = fn.replace(QChar(0xe4), "ae");
+      fn = fn.replace(QChar(0xf6), "oe");
+      fn = fn.replace(QChar(0xfc), "ue");
+      fn = fn.replace(QChar(0xdf), "ss");
+      fn = fn.replace(QChar(0xc4), "Ae");
+      fn = fn.replace(QChar(0xd6), "Oe");
+      fn = fn.replace(QChar(0xdc), "Ue");
+      fn = fn.replace( QRegExp( "[" + QRegExp::escape( "\\/:*?\"<>|" ) + "]" ), "_" ); //FAT/NTFS special chars
+      return fn;
+      }
+
 //---------------------------------------------------------
 //   load
 //    return true on error
@@ -143,7 +167,7 @@ bool LoadFile::load(const QString& name)
 bool MuseScore::checkDirty(Score* s)
       {
       if (s->dirty()) {
-            QMessageBox::StandardButton n = QMessageBox::warning(this, tr("MuseScore"),
+            QMessageBox::StandardButton n = QMessageBox::warning(this, "MuseScore",
                tr("Save changes to the score \"%1\"\n"
                "before closing?").arg(s->name()),
                QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel,
@@ -189,9 +213,13 @@ void MuseScore::loadFile()
          tr("Capella Files (*.cap);;")+
          tr("Bagpipe Music Writer Files (*.bww);;")+
          tr("BB Files <experimental> (*.mgu *.MGU *.sgu *.SGU);;")+
-         tr("Overture Files <experimental> (*.ove);;")+
-         tr("All Files (*)")
+         tr("Overture Files <experimental> (*.ove);;")
          );
+      openScore(fn);
+      }
+
+void MuseScore::openScore(const QString& fn)
+      {
       if (fn.isEmpty())
             return;
       Score* score = new Score(defaultStyle);
@@ -654,7 +682,7 @@ void MuseScore::newFile()
             newWizard->createInstruments(score);
             }
       if (!newWizard->title().isEmpty())
-            score->fileInfo()->setFile(newWizard->title());
+            score->fileInfo()->setFile(createDefaultFileName(newWizard->title()));
       for (int i = 0; i < measures; ++i) {
             Measure* measure = new Measure(score);
             score->measures()->add(measure);
@@ -697,11 +725,11 @@ void MuseScore::newFile()
                               // transpose key
                               //
                               KeySigEvent nKey = ks;
-                              if (part->transpose().chromatic && !newWizard->useTemplate()) {
+                              if (part->transpose().chromatic && !score->styleB(ST_concertPitch)) {
                                     int diff = -part->transpose().chromatic;
                                     nKey.setAccidentalType(transposeKey(nKey.accidentalType(), diff));
                                     }
-                              if (nKey.accidentalType()) {
+                              if (nKey.accidentalType() || newWizard->useTemplate()) {
                                     (*(staff->keymap()))[0] = nKey;
                                     KeySig* keysig = new KeySig(score);
                                     keysig->setTrack(staffIdx * VOICES);
@@ -867,11 +895,16 @@ void Score::saveCompressedFile(QIODevice* f, QFileInfo& info, bool autosave)
             QByteArray ba;
             if (!ip->loaded()) {
                   QFile inFile(srcPath);
-                  if (!inFile.open(QIODevice::ReadOnly))
-                        throw(QString("cannot open picture file"));
-                  ip->buffer().setData(inFile.readAll());
-                  inFile.close();
-                  ip->setLoaded(true);
+                  if (!inFile.open(QIODevice::ReadOnly)) {
+                        QMessageBox::warning(0, tr("Internal error"),
+                             tr("Cannot load picture file %1").arg(srcPath),
+                             QMessageBox::Ok, QMessageBox::NoButton);
+                        qDebug ("Cannot load picture file %s", qPrintable(srcPath));
+                        continue;
+                        }
+                   ip->buffer().setData(inFile.readAll());
+                   inFile.close();
+                   ip->setLoaded(true);
                   }
             cbuf.setBuffer(&(ip->buffer().buffer()));
             if (!cbuf.open(QIODevice::ReadOnly))
@@ -1207,10 +1240,15 @@ bool Score::read(QDomElement e)
             _mscVersion = sl[0].toInt() * 100 + sl[1].toInt();
             if (_mscVersion > MSCVERSION) {
                   // incompatible version
-                  QMessageBox::critical(0, tr("MuseScore"),
-                     QT_TRANSLATE_NOOP("score", "Cannot read this score:\n"
-                        "your version of MuseScore is too old.")
-                     );
+                  if(!noGui) {
+                        QString message = tr("Cannot read this score:<br>Your version of MuseScore is too old.<br><a href=\"%1\">Upgrade now!</a>").arg("http://musescore.org");
+                        QMessageBox msgBox;
+                        msgBox.setWindowTitle("MuseScore");
+                        msgBox.setText(message);
+                        msgBox.setTextFormat(Qt::RichText);
+                        msgBox.setIcon(QMessageBox::Critical);
+                        msgBox.exec();
+                        }
                   return false;
                   }
 
@@ -1250,8 +1288,8 @@ bool Score::read(QDomElement e)
 //                                                   v1, v2, v3, rv1, rv2, rv3);
 
                                                 int currentVersion = v1 * 10000 + v2 * 100 + v3;
-                                                int readVersion    = rv1 * 10000 + rv2 * 100 + rv3;
-                                                if (readVersion > currentVersion) {
+                                                _programVersion    = rv1 * 10000 + rv2 * 100 + rv3;
+                                                if (_programVersion > currentVersion) {
                                                       printf("read future version\n");
                                                       }
                                                 }
@@ -1526,7 +1564,8 @@ void Score::checkTuplets()
 
 void Score::printFile()
       {
-      QPrinter* printerDev = static_cast<QPrinter*>(pdev);
+      QPrinter pPrinter(QPrinter::HighResolution);
+      QPrinter *printerDev = &pPrinter;
 
       if (paperSizes[pageFormat()->size].qtsize == QPrinter::Custom) {
             printerDev->setPaperSize(QSizeF(pageFormat()->_width, pageFormat()->_height),
@@ -1645,15 +1684,13 @@ bool Score::savePsPdf(const QString& saveName, QPrinter::OutputFormat format)
 bool Score::saveSvg(const QString& saveName)
       {
       QSvgGenerator printer;
-      QPaintDevice* opdev = pdev;
-      pdev = &printer;
 
       printer.setResolution(int(DPI));
       printer.setFileName(saveName);
 
       _printing = true;
 
-      QPainter p(pdev);
+      QPainter p(&printer);
       p.setRenderHint(QPainter::Antialiasing, true);
       p.setRenderHint(QPainter::TextAntialiasing, true);
       double mag = converterDpi / DPI;
@@ -1699,7 +1736,6 @@ bool Score::saveSvg(const QString& saveName)
 
       _printing = false;
       p.end();
-      pdev = opdev;
       return true;
       }
 
@@ -1819,3 +1855,63 @@ bool Score::savePng(const QString& name, bool screenshot, bool transparent, doub
       return rv;
       }
 
+//---------------------------------------------------------
+//   collectTuplets
+//---------------------------------------------------------
+
+void Score::collectTuplets(QDomElement e, QList<Tuplet*>* tuplets)
+      {
+      QDomDocument doc = e.ownerDocument();
+
+      QString tag;
+      for (e = doc.documentElement(); !e.isNull(); e = e.nextSiblingElement()) {
+            tag = e.tagName();
+            if (tag == "museScore")
+                  break;
+            }
+      if (tag != "museScore") {
+            qDebug("  no museScore found");
+            return;
+            }
+
+      for (e = e.firstChildElement(); !e.isNull(); e = e.nextSiblingElement()) {
+            tag = e.tagName();
+            if (tag == "Score" || tag == "Part")
+                  break;
+            }
+      if (tag != "Score" && tag != "Part") {
+            qDebug("  no Score/Part found");
+            return;
+            }
+      if (tag == "Score")
+            e = e.firstChildElement();
+      else
+            e = e.nextSiblingElement();
+      for (; !e.isNull(); e = e.nextSiblingElement()) {
+            if (e.tagName() == "Staff") {
+                  for (QDomElement ee = e.firstChildElement(); !ee.isNull(); ee = ee.nextSiblingElement()) {
+                        if (ee.tagName() == "Measure") {
+                              for (QDomElement eee = ee.firstChildElement(); !eee.isNull(); eee = eee.nextSiblingElement()) {
+                                    if (eee.tagName() == "Tuplet") {
+                                          Tuplet* tuplet = new Tuplet(this);
+                                          QList<Slur*> slurList;
+                                          tuplet->read(eee, *tuplets, 0);
+                                          bool alreadyThere = false;
+                                          foreach(Tuplet* t, *tuplets) {
+                                                if (t->id() == tuplet->id()) {
+                                                      alreadyThere = true;
+                                                      break;
+                                                      }
+                                                }
+                                          if (!alreadyThere)
+                                                tuplets->append(tuplet);
+                                          else
+                                                delete tuplet;
+                                          }
+                                    }
+                              }
+                        }
+                  }
+            }
+      }
+
