@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: file.h 1840 2009-05-20 11:57:51Z wschweer $
+//  $Id: file.h 4136 2011-03-30 19:54:49Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -35,10 +35,10 @@ class LoadFile {
    public:
       LoadFile() {}
       virtual ~LoadFile() {}
-      virtual bool loader(QFile* f) = 0;
+      virtual bool loader(QFile* f) = 0;    // return false on error
       bool load(QWidget* parent, const QString& base, const QString& ext,
-         const QString& caption);
-      bool load(const QString& name);
+         const QString& caption);         // return false on error
+      bool load(const QString& name);     // return false on error
       QString name() const { return _name; }
       };
 
