@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: instrdialog.cpp 3798 2010-12-23 11:01:00Z lasconic $
+//  $Id: instrdialog.cpp 4340 2011-06-06 08:00:25Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -1052,7 +1052,7 @@ void InstrumentsDialog::on_loadButton_clicked()
       {
       QString fn = QFileDialog::getOpenFileName(
          this, tr("MuseScore: Load Instrument List"),
-          mscoreGlobalShare + "/templates",
+          mscoreGlobalShare + "templates",
          tr("MuseScore Instruments (*.xml);;"
             "All files (*)"
             )
