@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: key.cpp 3390 2010-08-15 11:57:08Z lasconic $
+//  $Id: key.cpp 5195 2012-01-06 16:58:35Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -22,6 +22,7 @@
 #include "xml.h"
 #include "utils.h"
 #include "score.h"
+#include "pitchspelling.h"
 
 //---------------------------------------------------------
 //   KeySigEvent
@@ -113,7 +114,7 @@ bool KeySigEvent::isValid() const
       }
 
 
-  
+
 //---------------------------------------------------------
 //   setCustomType
 //---------------------------------------------------------
@@ -182,7 +183,7 @@ void KeySigEvent::setNaturalType(int v)
       _naturalType = v;
 #endif
       }
-      
+
 //---------------------------------------------------------
 //   setCustom
 //---------------------------------------------------------
@@ -305,7 +306,7 @@ bool KeySigEvent::operator!=(const KeySigEvent& e) const
             return e._customType != _customType;
       else
             return e._accidentalType != _accidentalType;
-#endif      
+#endif
 
       }
 
@@ -370,8 +371,11 @@ void KeyList::removeTime(int tick, int len)
       {
       KeyList tmp;
       for (ciKeyList i = begin(); i != end(); ++i) {
-            if ((i->first >= tick) && (tick != 0)) {
-                  if (i->first >= tick + len)
+            if ((i->first >= tick)) {
+                  if (tick == 0 && tick == i->first) {
+                        tmp[i->first] = i->second;
+                        }
+                  else if (i->first >= tick + len)
                         tmp[i->first - len] = i->second;
                   else
                         printf("remove key event\n");
@@ -391,10 +395,16 @@ void KeyList::insertTime(int tick, int len)
       {
       KeyList tmp;
       for (ciKeyList i = begin(); i != end(); ++i) {
-            if ((i->first >= tick) && (tick != 0))
-                  tmp[i->first + len] = i->second;
+            if ((i->first >= tick)) {
+                  if (tick == 0 && tick == i->first) { //don't move the first one
+                        tmp[i->first] = i->second;
+                        }
+                  else{
+                        tmp[i->first + len] = i->second;
+                        }
+                  }
             else
-                  tmp[i->first] = i->second;
+                  tmp[i->first] = i->second; //don't move if < tick
             }
       clear();
       insert(tmp.begin(), tmp.end());
@@ -443,3 +453,30 @@ printf("  key %d\n", key);
       return key;
       }
 
+//---------------------------------------------------------
+//   initLineList
+//    preset lines list with accidentals for given key
+//---------------------------------------------------------
+
+void AccidentalState::init(int type)
+      {
+      memset(state, 2, 74);
+      for (int octave = 0; octave < 11; ++octave) {
+            if (type > 0) {
+                  for (int i = 0; i < type; ++i) {
+                        int idx = tpc2step(20 + i) + octave * 7;
+                        if (idx < 74)
+                              state[idx] = 1 + 2;
+                        }
+                  }
+            else {
+                  for (int i = 0; i > type; --i) {
+                        int idx = tpc2step(12 + i) + octave * 7;
+                        if (idx < 74)
+                              state[idx] = -1 + 2;
+                        }
+                  }
+            }
+      }
+
+
