@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: keyb.cpp 4447 2011-06-29 17:34:14Z wschweer $
+//  $Id: keyb.cpp 5442 2012-03-10 09:56:22Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -70,18 +70,22 @@ void ScoreView::editKey(QKeyEvent* ev)
                   found = true;
                   }
             else if (ev->key() == Qt::Key_Left) {
-                  if (!ctrl && e->edit(this, curGrip, key, modifiers, s))
+                  if (!ctrl && e->edit(this, curGrip, key, modifiers, s)) {
                         _score->end();
-                  else
+                        found = true;
+                        }
+                  /*else
                         lyricsTab(true, true, true);      // go to previous lyrics
-                  found = true;
+                  found = true;*/
                   }
             else if (ev->key() == Qt::Key_Right) {
-                  if (!ctrl && e->edit(this, curGrip, key, modifiers, s))
+                  if (!ctrl && e->edit(this, curGrip, key, modifiers, s)) {
                         _score->end();
-                  else
+                        found = true;
+                        }
+                  /*else
                         lyricsTab(false, false, true);    // go to next lyrics
-                  found = true;
+                  found = true;*/
                   }
             else if (ev->key() == Qt::Key_Up) {
                   lyricsUpDown(true, true);
@@ -133,18 +137,20 @@ void ScoreView::editKey(QKeyEvent* ev)
                   _score->end();
                   return;
                   }
-            if (e->isTextB() && (ev->key() == Qt::Key_Left || ev->key() == Qt::Key_Right)) {
+            if (e->isTextB() && (ev->key() == Qt::Key_Left || ev->key() == Qt::Key_Right) && !(modifiers & CONTROL_MODIFIER)) {
                   ev->accept();
                   _score->end();
                   //return;
                   }
             }
+            
       QPointF delta;
-      qreal val = 10.0;
+      qreal _spatium = editObject->spatium();
+      qreal val = 1.0 * _spatium;
       if (modifiers & Qt::ControlModifier)
-            val = 1.0;
+            val = 0.1 * _spatium;
       else if (modifiers & Qt::AltModifier)
-            val = 0.1;
+            val = 0.01 * _spatium;
       switch (ev->key()) {
             case Qt::Key_Left:
                   delta = QPointF(-val, 0);
@@ -163,6 +169,7 @@ void ScoreView::editKey(QKeyEvent* ev)
                   return;
             }
       e->editDrag(curGrip, delta);
+      _score->addRefresh(e->abbox().adjusted(-val, -val, 2*val, 2*val));
       updateGrips();
       _score->end();
       ev->accept();
