@@ -201,7 +201,8 @@ void KeyCanvas::dragEnterEvent(QDragEnterEvent* event)
             QDomElement e = doc.documentElement();
 
             QPointF dragOffset;
-            ElementType type = Element::readType(e, &dragOffset);
+            Fraction duration;  // dummy
+            ElementType type = Element::readType(e, &dragOffset, &duration);
             if (type != ACCIDENTAL)
                   return;
 
