@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: layout.cpp 4449 2011-06-30 13:06:36Z lasconic $
+//  $Id: layout.cpp 4911 2011-10-29 09:57:05Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -211,7 +211,8 @@ void Score::layoutChords1(Segment* segment, int staffIdx)
       bool isLeft   = notes[startIdx]->chord()->up();
       int move1     = notes[startIdx]->chord()->staffMove();
       bool mirror   = false;
-      int lastHead  = -1;
+      int lastHeadGroup  = -1;
+      int lastHeadType  = -1;
 
       for (int idx = startIdx; idx != endIdx; idx += incIdx) {
             Note* note   = notes[idx];
@@ -219,10 +220,12 @@ void Score::layoutChords1(Segment* segment, int staffIdx)
             int move     = chord->staffMove();
             int line     = note->line();
             int ticks    = chord->tickLen();
-            int head     = note->noteHead();      // symbol number or note head
+            int headGroup     = note->headGroup();      // symbol number or note head
+            int headType     =  (note->headType() == HEAD_AUTO) ? note->chord()->duration().headType() : note->headType() - 1;
 
             bool conflict = (qAbs(ll - line) < 2) && (move1 == move);
-            bool sameHead = (ll == line) && (head == lastHead);
+            bool sameHead = (ll == line) && (headGroup == lastHeadGroup) && (headType == lastHeadType);
+
             if ((chord->up() != isLeft) || conflict)
                   isLeft = !isLeft;
             bool nmirror  = (chord->up() != isLeft) && !sameHead;
@@ -273,7 +276,8 @@ void Score::layoutChords1(Segment* segment, int staffIdx)
 
             move1    = move;
             ll       = line;
-            lastHead = head;
+            lastHeadGroup = headGroup;
+            lastHeadType = headType;
             }
 
       //---------------------------------------------------
@@ -395,8 +399,8 @@ void Score::layoutStage1()
             for (int staffIdx = 0; staffIdx < nstaves(); ++staffIdx) {
                   KeySigEvent key = staff(staffIdx)->keymap()->key(m->tick());
 
-                  char tversatz[75];      // list of already set accidentals for this measure
-                  initLineList(tversatz, key.accidentalType());
+                  AccidentalState tversatz;      // list of already set accidentals for this measure
+                  tversatz.init(key.accidentalType());
 
                   m->setBreakMMRest(false);
                   if (styleB(ST_createMultiMeasureRests)) {
@@ -437,7 +441,7 @@ void Score::layoutStage1()
                               }
 
                         if ((segment->subtype() == SegChordRest) || (segment->subtype() == SegGrace))
-                              m->layoutChords0(segment, staffIdx * VOICES, tversatz);
+                              m->layoutChords0(segment, staffIdx * VOICES, &tversatz);
                         if (e && e->type() == KEYSIG) {
                               KeySigEvent oval = staff(staffIdx)->keymap()->key(e->tick() - 1);
                               static_cast<KeySig*>(e)->setOldSig(oval.accidentalType());
@@ -818,13 +822,15 @@ void Score::processSystemHeader(Measure* m, bool isFirstSystem)
                   // create missing key signature
                   //
                   KeySig* ks = keySigFactory(keyIdx);
-                  ks->setTrack(i * VOICES);
-                  ks->setTick(tick);
-                  ks->setGenerated(true);
-                  ks->setMag(staff->mag());
-                  Segment* seg = m->getSegment(ks);
-                  seg->add(ks);
-                  m->setDirty();
+                  if(ks) {
+                        ks->setTrack(i * VOICES);
+                        ks->setTick(tick);
+                        ks->setGenerated(true);
+                        ks->setMag(staff->mag());
+                        Segment* seg = m->getSegment(ks);
+                        seg->add(ks);
+                        m->setDirty();
+                        }
                   }
             else if (!needKeysig && hasKeysig) {
                   int track = hasKeysig->track();
