@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: lyrics.cpp 3247 2010-07-01 08:28:11Z lasconic $
+//  $Id: lyrics.cpp 3683 2010-11-07 16:56:32Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -573,7 +573,7 @@ void Lyrics::paste()
       QClipboard::Mode mode = QClipboard::Selection;
 #endif
       QString txt = QApplication::clipboard()->text(mode);
-      QStringList sl = txt.split(" ", QString::SkipEmptyParts);
+      QStringList sl = txt.split(QRegExp("\\s+"), QString::SkipEmptyParts);
       if (sl.isEmpty())
             return;
       cursor->insertText(sl[0]);
@@ -582,9 +582,8 @@ void Lyrics::paste()
       score()->setLayoutAll(lo);
       score()->setUpdateAll();
       score()->end();
-      txt = txt.mid(sl[0].size() + 1);
+      sl.removeFirst();
+      txt = sl.join(" ");   
       QApplication::clipboard()->setText(txt, mode);
-
-//TODO-S      score()->lyricsTab(false, true);
       }
 
