@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: mididriver.cpp 2154 2009-10-03 14:31:53Z wschweer $
+//  $Id: mididriver.cpp 3947 2011-01-24 18:23:59Z wschweer $
 //
 //  Copyright (C) 2008 Werner Schweer and others
 //
@@ -354,7 +354,7 @@ void AlsaMidiDriver::read()
       snd_seq_event_t* ev;
       for (;;) {
             int rv = snd_seq_event_input(alsaSeq, &ev);
-            if (rv < 0)
+            if (rv < 0 || mscore == 0)
                   return;
 
             if (!mscore->midiinEnabled()) {
