@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: musedata.cpp 2636 2010-01-21 18:02:33Z wschweer $
+//  $Id: musedata.cpp 3912 2011-01-18 12:28:38Z lasconic $
 //
 //  Copyright (C) 2007 Werner Schweer and others
 //
@@ -457,14 +457,14 @@ void MuseData::readRest(Part* part, const QString& s)
       d.setVal(ticks);
       Rest* rest = new Rest(score, tick, d);
       chordRest  = rest;
-      rest->setTrack(staffIdx * VOICES);
+      rest->setTrack(gstaff * VOICES);
       Segment* segment = measure->getSegment(rest);
 
       voice = 0;
       for (; voice < VOICES; ++voice) {
             Element* e = segment->element(gstaff * VOICES + voice);
             if (e == 0) {
-                  rest->setTrack(staffIdx * VOICES + voice);
+                  rest->setTrack(gstaff * VOICES + voice);
                   segment->add(rest);
                   break;
                   }
@@ -684,7 +684,8 @@ bool MuseData::read(const QString& name)
                               }
                         }
                   score->appendPart(mpart);
-                  mpart->setLongName(part[8]);
+                  if(part.size() > 8)
+                        mpart->setLongName(part[8]);
                   part.clear();
                   continue;
                   }
