@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: newwizard.cpp 2931 2010-04-02 14:14:12Z wschweer $
+//  $Id: newwizard.cpp 5688 2013-02-18 17:44:59Z lasconic $
 //
 //  Copyright (C) 2008 Werner Schweer and others
 //
@@ -677,14 +677,18 @@ QString NewWizardPage4::templatePath() const
 NewWizard::NewWizard(QWidget* parent)
    : QWizard(parent)
       {
+#ifdef Q_WS_MAC      
+      setWizardStyle(QWizard::ClassicStyle);
+#else
       setPixmap(QWizard::LogoPixmap, QPixmap(":/data/mscore.png"));
       setPixmap(QWizard::WatermarkPixmap, QPixmap(":/data/bg1.jpg"));
+#endif      
       setWindowTitle(tr("MuseScore: Create New Score"));
-    setOption(QWizard::NoCancelButton, false);
-    setOption(QWizard::CancelButtonOnLeft, true);
-    setOption(QWizard::HaveFinishButtonOnEarlyPages, true);
-    setOption(QWizard::HaveNextButtonOnLastPage, true);
-
+      
+      setOption(QWizard::NoCancelButton, false);
+      setOption(QWizard::CancelButtonOnLeft, true);
+      setOption(QWizard::HaveFinishButtonOnEarlyPages, true);
+      setOption(QWizard::HaveNextButtonOnLastPage, true);
 
       p1 = new NewWizardPage1;
       p2 = new NewWizardPage2;
