@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: note.cpp 4464 2011-07-03 15:45:09Z lasconic $
+//  $Id: note.cpp 5456 2012-03-12 10:40:29Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -1038,6 +1038,8 @@ Element* Note::drop(ScoreView* view, const QPointF& p1, const QPointF& p2, Eleme
                   e->setParent(ch);
                   score()->undoRemoveElement(this);
                   score()->undoAddElement(e);
+                  if(selected())
+                        score()->select(e, SELECT_SINGLE, 0);
                   }
                   break;
 
@@ -1116,7 +1118,7 @@ Element* Note::drop(ScoreView* view, const QPointF& p1, const QPointF& p2, Eleme
                   break;
 
             default:
-                  return ch->drop(view, p1, p2, e);
+                  return ch->drop(view, p1, p2, e, Fraction (1,4));
             }
       return 0;
       }
@@ -1218,7 +1220,7 @@ void Note::layout()
 //    compute actual accidental and line
 //---------------------------------------------------------
 
-void Note::layout1(char* tversatz)
+void Note::layout1(AccidentalState* tversatz)
       {
       _line          = tpc2step(_tpc) + (_pitch/12) * 7;
       int tpcPitch   = tpc2pitch(_tpc);
@@ -1233,12 +1235,15 @@ void Note::layout1(char* tversatz)
       else  {
             int accVal = ((_tpc + 1) / 7) - 2;
             acci       = ACC_NONE;
-            if ((accVal != tversatz[_line]) || hidden()) {
-                  if (_tieBack == 0)
-                        tversatz[_line] = accVal;
-                  acci = Accidental::value2subtype(accVal);
-                  if (acci == ACC_NONE)
-                        acci = ACC_NATURAL;
+            if ((accVal != tversatz->accidentalVal(_line)) || hidden() || tversatz->tieContext(_line)) {
+                  tversatz->setAccidentalVal(_line, accVal, _tieBack != 0);
+                  if (_tieBack)
+                        acci = ACC_NONE;
+                  else {
+                        acci = Accidental::value2subtype(accVal);
+                        if (acci == ACC_NONE)
+                              acci = ACC_NATURAL;
+                        }
                   }
             }
       if (acci != ACC_NONE && !_tieBack && !_hidden) {
