@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: palette.cpp 4560 2011-07-20 09:54:10Z lasconic $
+//  $Id: palette.cpp 5316 2012-02-13 10:43:46Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -37,6 +37,7 @@
 #include "seq.h"
 #include "part.h"
 #include "textline.h"
+#include "slur.h"
 
 //---------------------------------------------------------
 //   needsStaff
@@ -680,7 +681,8 @@ void Palette::dropEvent(QDropEvent* event)
             docName = "--";
             QDomElement el = doc.documentElement();
             QPointF dragOffset;
-            ElementType type = Element::readType(el, &dragOffset);
+            Fraction duration;  // dummy
+            ElementType type = Element::readType(el, &dragOffset, &duration);
 
             if (type == IMAGE) {
                   // look ahead for image type
@@ -935,6 +937,10 @@ void Palette::read(QDomElement e)
                                           }
                                     else {
                                           element->read(ee);
+                                          if(element->type() == SLUR) {
+                                                Slur* s = static_cast<Slur*>(element);
+                                                s->setLen(gscore->spatium() * 7);
+                                                }
                                           append(element, name);
                                           }
                                     }
