@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: pitchspelling.cpp 3269 2010-07-09 20:20:39Z lasconic $
+//  $Id: pitchspelling.cpp 5195 2012-01-06 16:58:35Z lasconic $
 //
 //  Copyright (C) 2007 Werner Schweer and others
 //
@@ -160,6 +160,8 @@ void tpc2name(int tpc, bool germanNames, QChar* name, int* acc)
       *acc   = ((tpc+1) / 7) - 2;
       int idx = (tpc + 1) % 7;
       *name = QChar::fromLatin1(germanNames ? gnames[idx] : names[idx]);
+      if (*name == 'H' && *acc == -1)
+              *name = 'B';      
       }
 
 //---------------------------------------------------------
