@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: preferences.cpp 4585 2011-07-24 06:27:19Z lasconic $
+//  $Id: preferences.cpp 5687 2013-02-18 16:42:23Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -146,9 +146,9 @@ void Preferences::init()
       usePortaudioAudio  = true;
       useJackMidi        = false;
 #else
-      useAlsaAudio       = true;
+      useAlsaAudio       = false;
       useJackAudio       = false;
-      usePortaudioAudio  = false;
+      usePortaudioAudio  = true;
       useJackMidi        = false;
 #endif
       alsaDevice         = "default";
@@ -163,7 +163,7 @@ void Preferences::init()
       layoutBreakColor         = Qt::green;
       antialiasedDrawing       = true;
       sessionStart             = SCORE_SESSION;
-      startScore               = ":/data/Promenade_Example.mscx";
+      startScore               = ":/data/Reunion_Example.mscz";
       workingDirectory         = QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation);
       showSplashScreen         = true;
 
@@ -208,9 +208,9 @@ void Preferences::init()
       twosided                = true;
       spatium                 = SPATIUM20;
       tuning                  = 440.0f;
-      masterGain              = 0.2;
-      chorusGain              = 0.5;
-      reverbGain              = 0.2;
+      masterGain              = 0.3;
+      chorusGain              = 0.0;
+      reverbGain              = 0.0;
       reverbRoomSize          = 0.5;
       reverbDamp              = 0.5;
       reverbWidth             = 1.0;
@@ -219,11 +219,15 @@ void Preferences::init()
       warnPitchRange          = true;
       followSong              = true;
       importCharset           = "GBK";
+      
+      useOsc                  = false;
+      oscPort                 = 5282;
 
       //update
       checkUpdateStartup      = 0;
       
       firstStartWeb = true;
+      firstStart12 = true;
       };
 
 //---------------------------------------------------------
@@ -327,6 +331,7 @@ void Preferences::write()
       s.setValue("followSong", followSong);
       
       s.setValue("firstStartWeb", firstStartWeb);
+      s.setValue("firstStart12", false);
 
       //update
       s.setValue("checkUpdateStartup", checkUpdateStartup);
@@ -378,10 +383,10 @@ void Preferences::read()
       useJackMidi        = s.value("useJackMidi",  false).toBool();
       usePortaudioAudio  = s.value("usePortaudioAudio", true).toBool();
 #else
-      useAlsaAudio       = s.value("useAlsaAudio", true).toBool();
+      useAlsaAudio       = s.value("useAlsaAudio", false).toBool();
       useJackAudio       = s.value("useJackAudio", false).toBool();
       useJackMidi        = s.value("useJackMidi",  false).toBool();
-      usePortaudioAudio  = s.value("usePortaudioAudio", false).toBool();
+      usePortaudioAudio  = s.value("usePortaudioAudio", true).toBool();
 #endif
 
       alsaDevice         = s.value("alsaDevice", "default").toString();
@@ -423,9 +428,9 @@ void Preferences::read()
       twosided               = s.value("twosided", true).toBool();
       spatium                = s.value("spatium", SPATIUM20).toDouble();
       tuning                 = s.value("tuning", 440.0).toDouble();
-      masterGain             = s.value("masterGain", 0.2).toDouble();
-      chorusGain             = s.value("chorusGain", 0.5).toDouble();
-      reverbGain             = s.value("reverbGain", 0.2).toDouble();
+      masterGain             = s.value("masterGain", 0.3).toDouble();
+      chorusGain             = s.value("chorusGain", 0.0).toDouble();
+      reverbGain             = s.value("reverbGain", 0.0).toDouble();
       reverbRoomSize         = s.value("reverbRoomSize", 0.5).toDouble();
       reverbDamp             = s.value("reverbDamp", 0.5).toDouble();
       reverbWidth            = s.value("reverbWidth", 1.0).toDouble();
@@ -437,6 +442,7 @@ void Preferences::read()
       followSong             = s.value("followSong", true).toBool();
       
       firstStartWeb = s.value("firstStartWeb", true).toBool();
+      firstStart12 = s.value("firstStart12", true).toBool();
 
       checkUpdateStartup = s.value("checkUpdateStartup", UpdateChecker::defaultPeriod()).toInt();
       if (checkUpdateStartup == 0){
@@ -453,7 +459,9 @@ void Preferences::read()
       else if (ss == "empty")
             sessionStart = EMPTY_SESSION;
 
-      startScore     = s.value("startScore", ":/data/Promenade_Example.mscx").toString();
+      startScore     = s.value("startScore", ":/data/Reunion_Example.mscz").toString();
+      if(startScore == ":/data/Promenade_Example.mscx")
+            startScore = ":/data/Reunion_Example.mscz";
       instrumentList = s.value("instrumentList", ":/data/instruments.xml").toString();
 
       readShortcuts();
@@ -814,7 +822,7 @@ void PreferenceDialog::updateSCListView()
                   continue;
             ShortcutItem* newItem = new ShortcutItem;
             newItem->setText(0, s->descr);
-            newItem->setIcon(0, *icons[s->icon]);
+            //newItem->setIcon(0, *icons[s->icon]);
             if(!s->key.isEmpty())
                 newItem->setText(1, s->key.toString(QKeySequence::NativeText));
             else{
@@ -1055,11 +1063,7 @@ void PreferenceDialog::apply()
          || (preferences.alsaPeriodSize != alsaPeriodSize->currentText().toInt())
          || (preferences.alsaFragments != alsaFragments->value())
             ) {
-            seq->stop();
-#ifndef __MINGW32__
-            while(!seq->isStopped())
-                  usleep(50000);
-#endif
+            seq->stopWait();
             seq->exit();
             preferences.useAlsaAudio       = alsaDriver->isChecked();
             preferences.useJackAudio       = jackDriver->isChecked();
