@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: rendermidi.cpp 5374 2012-02-24 18:55:11Z lasconic $
+//  $Id: rendermidi.cpp 5681 2013-02-18 14:16:08Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -676,8 +676,8 @@ void Score::fixPpitch()
                   }
             }
 #ifdef Q_WS_MAC      
-      delete velo;
-      delete osl;
+      delete[] velo;
+      delete[] osl;
 #endif
       }
 
