@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: repeatlist.cpp 3503 2010-09-24 12:09:37Z lasconic $
+//  $Id: repeatlist.cpp 4084 2011-03-09 19:12:01Z lasconic $
 //
 //  Copyright (C) 2009 Werner Schweer and others
 //
@@ -117,6 +117,19 @@ int RepeatList::utick2tick(int tick) const
       return 0;
       }
 
+//---------------------------------------------------------
+//   tick2utick
+//---------------------------------------------------------
+
+int RepeatList::tick2utick(int tick) const
+      {
+      foreach (const RepeatSegment* s, *this) {
+            if (tick >= s->tick && tick < (s->tick + s->len))
+                  return s->utick + (tick - s->tick);
+            }
+      return 0;
+      }
+
 //---------------------------------------------------------
 //   utick2utime
 //---------------------------------------------------------
