@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: scchord.cpp 3801 2010-12-23 12:12:27Z lasconic $
+//  $Id: scchord.cpp 4379 2011-06-14 11:23:05Z lasconic $
 //
 //  Copyright (C) 2009-2010 Werner Schweer and others
 //
@@ -33,10 +33,10 @@ Q_DECLARE_METATYPE(Score*);
 Q_DECLARE_METATYPE(Note*);
 
 static const char* const function_names_chord[] = {
-      "tickLen", "addHarmony", "topNote", "addNote", "removeNote", "notes", "note", "type", "lyrics"
+      "tickLen", "addHarmony", "topNote", "addNote", "removeNote", "notes", "note", "type", "lyrics", "noStem", "small"
       };
 static const int function_lengths_chord[] = {
-      1, 1, 0, 1, 1, 0, 1, 0, 0
+      1, 1, 0, 1, 1, 0, 1, 0, 0, 1, 1
       };
 static const QScriptValue::PropertyFlags flags_chord[] = {
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter,
@@ -47,11 +47,13 @@ static const QScriptValue::PropertyFlags flags_chord[] = {
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::ReadOnly,
       QScriptValue::SkipInEnumeration,
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::ReadOnly,
-      QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::ReadOnly
+      QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::ReadOnly,
+      QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter,
+      QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter
       };
 
 ScriptInterface chordInterface = {
-      9,
+      sizeof(function_names_chord) / sizeof(*function_names_chord),
       function_names_chord,
       function_lengths_chord,
       flags_chord
@@ -76,7 +78,7 @@ static QScriptValue prototype_Chord_call(QScriptContext* context, QScriptEngine*
             }
             
       switch(_id) {
-            case 0:
+            case 0: //tickLen
                   if (context->argumentCount() == 0)
                         return qScriptValueFromValue(context->engine(), chord->tickLen());
                   else if (context->argumentCount() == 1) {
@@ -87,7 +89,7 @@ static QScriptValue prototype_Chord_call(QScriptContext* context, QScriptEngine*
                         return context->engine()->undefinedValue();
                         }
                   break;
-            case 1:
+            case 1: //addHarmony
                   if (context->argumentCount() == 1) {
                         Harmony* h = qscriptvalue_cast<Harmony*>(context->argument(0));
                         if (!h)
@@ -159,11 +161,35 @@ static QScriptValue prototype_Chord_call(QScriptContext* context, QScriptEngine*
             case 7:     // "type"
                   return qScriptValueFromValue(context->engine(), int(chord->noteType()));
             case 8:     // "lyric"
+                  {
                   QStringList ll; 
                   LyricsList * lyrlist = chord->segment()->lyricsList(0);
 	                for (ciLyrics lix = lyrlist->begin(); lix != lyrlist->end(); ++lix)      
                       ll.append((*lix)->getText());
                   return qScriptValueFromValue(context->engine(), ll);
+                  }
+            case 9:     //noStem
+                 {
+                 if (context->argumentCount() == 0) {
+                      return qScriptValueFromValue(context->engine(), chord->noStem());
+                      }
+                 else if (context->argumentCount() == 1) {
+                      bool noStem = context->argument(0).toBool();
+                      chord->score()->undoChangeChordNoStem(chord, noStem);
+                      }
+                return context->engine()->undefinedValue();
+                }
+            case 10:     //small
+                 {
+                 if (context->argumentCount() == 0) {
+                      return qScriptValueFromValue(context->engine(), chord->small());
+                      }
+                 else if (context->argumentCount() == 1) {
+                      bool small = context->argument(0).toBool();
+                      chord->score()->undoChangeChordRestSize(chord, small);
+                      }
+                return context->engine()->undefinedValue();
+                }
             }
       return context->throwError(QScriptContext::TypeError,
          QString::fromLatin1("Chord.%0(): bad argument count or value")
