@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: scnote.cpp 3489 2010-09-21 14:49:55Z lasconic $
+//  $Id: scnote.cpp 4406 2011-06-21 17:40:33Z lasconic $
 //
 //  Copyright (C) 2009-2010 Werner Schweer and others
 //
@@ -32,10 +32,11 @@ Q_DECLARE_METATYPE(Note*);
 Q_DECLARE_METATYPE(Score*);
 
 static const char* const function_names_note[] = {
-      "name", "pitch", "tuning", "color", "visible", "tpc", "tied", "userAccidental", "boundingRect", "pos", "noteHead"
+      "name", "pitch", "tuning", "color", "visible", "tpc", "tied", "userAccidental", 
+      "boundingRect", "pos", "noteHead", "velocity"
       };
 static const int function_lengths_note[] = {
-      0, 1, 1, 1, 1, 1, 0, 1, 0, 0,0
+      0, 1, 1, 1, 1, 1, 0, 1, 0, 0, 1, 1
       };
 
 static const QScriptValue::PropertyFlags flags_note[] = {
@@ -47,13 +48,14 @@ static const QScriptValue::PropertyFlags flags_note[] = {
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter,
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter,
       QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter,
-	  QScriptValue::SkipInEnumeration,
-	  QScriptValue::SkipInEnumeration,
-	  QScriptValue::SkipInEnumeration
+  	  QScriptValue::SkipInEnumeration,
+  	  QScriptValue::SkipInEnumeration,
+  	  QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter,
+  	  QScriptValue::SkipInEnumeration | QScriptValue::PropertyGetter | QScriptValue::PropertySetter
       };
 
 ScriptInterface noteInterface = {
-      11,
+      sizeof(function_names_note) / sizeof(*function_names_note),
       function_names_note,
       function_lengths_note,
       flags_note
@@ -93,8 +95,18 @@ static QScriptValue prototype_Note_call(QScriptContext* context, QScriptEngine*)
                         int pitch = context->argument(0).toInt32();
                         if (pitch < 0 || pitch > 127)
                               break;
-                        note->setPitch(pitch);
-                        note->setTpcFromPitch();
+                        Score* score = note->score();
+                        if (score) {
+                              Note* tmp = note->clone();
+                              tmp->setPitch(pitch);
+                              tmp->setTpcFromPitch();
+                              score->undoChangePitch(note, pitch, tmp->tpc(), note->userAccidental());
+                              delete tmp;
+                              }
+                        else {
+                              note->setPitch(pitch);
+                              note->setTpcFromPitch();
+                              }
                         return context->engine()->undefinedValue();
                         }
                   break;
@@ -103,7 +115,13 @@ static QScriptValue prototype_Note_call(QScriptContext* context, QScriptEngine*)
                         return qScriptValueFromValue(context->engine(), note->tuning());
                   else if (argc == 1) {
                         double tuning = context->argument(0).toNumber();
-                        note->setTuning(tuning);
+                        Score* score = note->score();
+                        if (score) {
+                              score->undoChangeTuning(note, tuning);
+                              }
+                        else{
+                              note->setTuning(tuning);
+                              }
                         return context->engine()->undefinedValue();
                         }
                   break;
@@ -173,6 +191,43 @@ static QScriptValue prototype_Note_call(QScriptContext* context, QScriptEngine*)
 			case 10:     // "noteHead"
 				  if (context->argumentCount() == 0)
 					  return qScriptValueFromValue(context->engine(), note->noteHead());
+					else if (context->argumentCount() == 1) {
+      				  int v = context->argument(0).toInt32();
+                if(v < HEAD_GROUPS) {
+                      Score* score = note->score();
+                      if (score)
+                            score->undo()->push(new ChangeNoteHead(note, v, note->headType())); 
+                      else 
+                            note->setHeadGroup(v);
+                      }
+                return context->engine()->undefinedValue();
+                }
+				  break;
+      case 11:     // "velocity"
+				  if (context->argumentCount() == 0)
+					  return qScriptValueFromValue(context->engine(), note->velocity());
+					else if (context->argumentCount() == 1) {
+      				  int v = context->argument(0).toInt32();
+      				  Score* score = note->score();
+                if (!score)
+                     return context->engine()->undefinedValue();  
+                if(v < 0) {
+                      if (note->veloType() != AUTO_VAL) {
+                            score->undo()->push(new ChangeNoteProperties(note,
+                                AUTO_VAL, note->velocity(), note->veloOffset(),
+                                note->onTimeType(), note->onTimeOffset(), note->onTimeUserOffset(),
+                                note->offTimeType(), note->offTimeOffset(), note->offTimeUserOffset()));
+                                score->fixPpitch();
+                            }  
+                     }
+                else if (v < 127) {
+                      score->undo()->push(new ChangeNoteProperties(note,
+                           USER_VAL, v, note->veloOffset(),
+                           note->onTimeType(), note->onTimeOffset(), note->onTimeUserOffset(),
+                           note->offTimeType(), note->offTimeOffset(), note->offTimeUserOffset()));
+                      }
+                return context->engine()->undefinedValue();
+                }
 				  break;
             }
       return context->throwError(QScriptContext::TypeError,
