@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: score.cpp 5407 2012-03-03 14:17:18Z lasconic $
+//  $Id: score.cpp 5677 2013-02-16 12:24:34Z lasconic $
 //
 //  Copyright (C) 2002-2008 Werner Schweer and others
 //
@@ -2185,3 +2185,19 @@ Text* Score::getText(int subtype)
       return 0;
       }
 
+//---------------------------------------------------------
+//   cleanVoltas
+//---------------------------------------------------------
+void Score::cleanVoltas() 
+      {
+      foreach(Element* gel, _gel) {
+            if(gel->type() == VOLTA) {
+                  Volta* volta = static_cast<Volta*>(gel);
+                  if (volta->staffIdx() >= staves().size()) {
+                        removeElement(volta);
+                        qDebug("remove volta staffidx %d size %d", volta->staffIdx(), staves().size());
+                        }
+                  }
+            }
+      }
+
