@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: score.h 4439 2011-06-28 12:11:24Z lasconic $
+//  $Id: score.h 5677 2013-02-16 12:24:34Z lasconic $
 //
 //  Copyright (C) 2002-2010 Werner Schweer and others
 //
@@ -261,8 +261,9 @@ class Score : public QObject {
                                       ///< indicating if playPos after expanded repeats
                                       ///< has been calculated.
 
-      int _fileDivision; ///< division of current loading *.msc file
-      int _mscVersion;   ///< version of current loading *.msc file
+      int _fileDivision; ///< division of current loading *.mscx file
+      int _mscVersion;   ///< version of current loading *.mscx file
+      int _programVersion; // the actual program version the file has been created with
 
       QString _movementNumber;       // some meta data; used for musicXML
       QString _movementTitle;
@@ -314,7 +315,7 @@ class Score : public QObject {
       void addTempo();
       void addMetronome();
 
-     
+
 
       void cmdAddChordName2();
       int processPendingNotes(QList<MNote*>* notes, int, int);
@@ -328,7 +329,6 @@ class Score : public QObject {
       void cmdInsertClef(int type);
       void cmdExchangeVoice(int, int);
 
-      void updateSelectedElements();
       void removeChordRest(ChordRest* cr, bool clearSegment);
       void cmdMove(Element* e, QPointF delta);
 
@@ -373,6 +373,8 @@ class Score : public QObject {
 
       TextC* rights;                ///< Copyright printed at bottom of page
 
+      void updateSelectedElements();
+
       void cmdAppendMeasures(int);
       void cmdInsertMeasures(int);
       bool noStaves() const         { return _staves.empty(); }
@@ -578,6 +580,7 @@ class Score : public QObject {
 
       Element* getSelectedElement() const   { return _selection.element(); }
       const Selection& selection() const    { return _selection; }
+      Selection& selection()                { return _selection; }
       void setSelection(const Selection& s);
 
       int pos();
@@ -658,6 +661,9 @@ class Score : public QObject {
       int mscVersion() const    { return _mscVersion; }
       void setMscVersion(int v) { _mscVersion = v; }
 
+      int programVersion() const    { return _programVersion; }
+      void setProgramVersion(int v) { _programVersion = v; }
+
       AL::TimeSigMap* sigmap()  { return _sigmap; }
       MeasureBase* appendMeasure(int type);
       void addLyrics(int tick, int staffIdx, const QString&);
@@ -793,6 +799,8 @@ class Score : public QObject {
       void enqueueMidiEvent(MidiInputEvent ev) { midiInputQueue.enqueue(ev); }
       void doLayout();
       void layoutChords1(Segment* segment, int staffIdx);
+      void collectTuplets(QDomElement e, QList<Tuplet*>* tuplets);
+      void cleanVoltas();
       };
 
 extern Score* gscore;
