@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: segment.cpp 3233 2010-06-28 12:54:32Z wschweer $
+//  $Id: segment.cpp 3745 2010-12-08 09:26:36Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -320,8 +320,10 @@ void Segment::add(Element* el)
                         measure()->mstaff(staffIdx)->hasVoices = true;
 
             default:
-                  _elist[track] = el;
-                  empty = false;
+                  if(track < _elist.size()) {
+                        _elist[track] = el;
+                        empty = false;
+                        }
                   break;
             }
       }
@@ -503,4 +505,15 @@ void Segment::checkEmpty() const
             }
       }
 
+//---------------------------------------------------------
+//   swapElements
+//---------------------------------------------------------
 
+void Segment::swapElements(int i1, int i2)
+      {
+      _elist.swap(i1, i2);
+      if (_elist[i1])
+            _elist[i1]->setTrack(i1);
+      if (_elist[i2])
+            _elist[i2]->setTrack(i2);
+      }
