@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: select.cpp 4493 2011-07-07 07:12:32Z lasconic $
+//  $Id: select.cpp 5447 2012-03-11 09:47:42Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -814,8 +814,8 @@ QByteArray Selection::staffMimeData() const
                                           }
                                     foreach(Tuplet* t, tl) {
                                           if (t->id() == -1) {
-                                                tuplet->setId(xml.tupletId++);
-                                                tuplet->write(xml);
+                                                t->setId(xml.tupletId++);
+                                                t->write(xml);
                                                 }
                                           }
                                     }
@@ -1018,10 +1018,12 @@ void Score::selectElementDialog(Element* e)
       }
 
 //---------------------------------------------------------
-//   isInMiddleOfTuplet
+//   checkStart
+//     return false if element is NOT a tuplet or is start of a tuplet
+//     return true  if element is part of a tuplet, but not the start
 //---------------------------------------------------------
 
-static bool isInMiddleOfTuplet(Element* e)
+static bool checkStart(Element* e)
       {
       if (e == 0 || !e->isChordRest())
             return false;
@@ -1032,6 +1034,26 @@ static bool isInMiddleOfTuplet(Element* e)
       while (tuplet) {
             if (tuplet->elements().front() == e)
                   return false;
+            tuplet = tuplet->tuplet();
+            }
+      return true;
+      }
+
+//---------------------------------------------------------
+//   checkEnd
+//     return false if element is NOT a tuplet or is end of a tuplet
+//     return true  if element is part of a tuplet, but not the end
+//---------------------------------------------------------
+
+static bool checkEnd(Element* e)
+      {
+      if (e == 0 || !e->isChordRest())
+            return false;
+      ChordRest* cr = static_cast<ChordRest*>(e);
+      if (!cr->tuplet())
+            return false;
+      Tuplet* tuplet = cr->tuplet();
+      while (tuplet) {
             if (tuplet->elements().back() == e)
                   return false;
             tuplet = tuplet->tuplet();
@@ -1049,12 +1071,24 @@ bool Selection::canCopy() const
       if (_state != SEL_RANGE)
             return true;
 
-      for (int staffIdx = _staffStart; staffIdx != _staffEnd; ++staffIdx) {
-            if (isInMiddleOfTuplet(_startSegment->element(staffIdx)))
-                  return false;
-            if (_endSegment && isInMiddleOfTuplet(_endSegment->element(staffIdx)))
-                  return false;
-            }
+      for (int staffIdx = _staffStart; staffIdx != _staffEnd; ++staffIdx)
+            for (int voice = 0; voice < VOICES; ++voice) {
+                  int track = staffIdx * VOICES + voice;
+                  if (checkStart(_startSegment->element(track)))
+                        return false;
+
+                  if (! _endSegment)
+                        continue;
+
+                  // find last segment in the selection.
+                  // Note that _endSegment is the first segment after the selection
+                  Segment *endSegmentSelection = _startSegment;
+                  while (endSegmentSelection->nextCR(track) &&
+                        (endSegmentSelection->nextCR(track)->tick() < _endSegment->tick()))
+                        endSegmentSelection = endSegmentSelection->nextCR(track);
+
+                  if (checkEnd(endSegmentSelection->element(track)))
+                        return false;
+                  }
       return true;
       }
-
