@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: seq.cpp 5405 2012-03-03 12:35:29Z lasconic $
+//  $Id: seq.cpp 5698 2013-02-20 16:16:16Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -107,6 +107,22 @@ Seq::~Seq()
       {
       delete driver;
       }
+      
+//---------------------------------------------------------
+//   stopWait
+//---------------------------------------------------------
+
+void Seq::stopWait()
+      {
+      stop();
+      QMutex mutex;
+      QWaitCondition sleep;
+      while (state != STOP) {
+            mutex.lock();
+            sleep.wait(&mutex, 100);
+            mutex.unlock();
+            }
+      }
 
 //---------------------------------------------------------
 //   setScoreView
@@ -117,12 +133,8 @@ void Seq::setScoreView(ScoreView* v)
       if (cv !=v && cs) {
             disconnect(cs, SIGNAL(selectionChanged(int)), this, SLOT(selectionChanged(int)));
             markedNotes.clear();
-            stop();
+            stopWait();
             cs = v ? v->score() : 0;
-#ifndef __MINGW32__
-            while (state != STOP)
-                  usleep(100000);
-#endif
             }
       cv = v;
       cs = cv ? cv->score() : 0;
@@ -274,7 +286,7 @@ void Seq::exit()
       if (driver) {
             if (debugMode)
                   printf("Stop I/O\n");
-            driver->stop();
+            stopWait();
             delete driver;
             driver = 0;
             }
@@ -481,6 +493,8 @@ void Seq::startTransport()
 
 void Seq::playEvent(const Event* event, unsigned framePos)
       {
+      if(!event)
+            return;
       int type = event->type();
       if (type == ME_NOTEON) {
             bool mute;
@@ -666,6 +680,9 @@ void Seq::initInstruments()
 
 void Seq::collectEvents()
       {
+      //do not collect even while playing
+      if (state == PLAY)
+            return;
       foreach(Event* e, events)
             delete e;
       events.clear();
@@ -946,7 +963,8 @@ void Seq::sendEvent(const Event& ev)
 
 void Seq::nextMeasure()
       {
-      EventMap::const_iterator i = playPos;
+      int tick  = playPos.key();
+      EventMap::const_iterator i = events.upperBound(tick);
       Note* note = 0;
       for (;;) {
             if (i.value()->type() == ME_NOTEON) {
@@ -975,7 +993,7 @@ void Seq::nextMeasure()
 void Seq::nextChord()
       {
       int tick = playPos.key();
-      for (EventMap::const_iterator i = playPos; i != events.constEnd(); ++i) {
+      for (EventMap::const_iterator i = events.upperBound(tick); i != events.constEnd(); ++i) {
             if (i.value()->type() != ME_NOTEON)
                   continue;
             Event* n = i.value();
@@ -992,7 +1010,8 @@ void Seq::nextChord()
 
 void Seq::prevMeasure()
       {
-      EventMap::const_iterator i = playPos;
+      int tick  = playPos.key();
+      EventMap::const_iterator i = events.lowerBound(tick);;
       Note* note = 0;
       for (;;) {
             if (i.value()->type() == ME_NOTEON) {
@@ -1024,7 +1043,7 @@ void Seq::prevChord()
       {
       int tick  = playPos.key();
       //find the chord just before playpos
-      EventMap::const_iterator i = playPos;
+      EventMap::const_iterator i = events.lowerBound(tick);
       for (;;) {
             if (i.value()->type() == ME_NOTEON) {
                   Event* n = i.value();
