@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: slur.cpp 4095 2011-03-14 16:07:28Z lasconic $
+//  $Id: slur.cpp 5424 2012-03-06 22:37:09Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -353,8 +353,8 @@ void SlurSegment::layout(const QPointF& p1, const QPointF& p2, qreal b)
 
       qreal xdelta = x3 - x0;
       if (xdelta == 0.0) {
-            printf("warning: slur has zero width at %d-%d\n",
-               slurTie()->startElement()->tick(), slurTie()->endElement()->tick());
+            if(debugMode)
+                  printf("warning: slur has zero width\n");
             return;
             }
       if (x0 > x3) {
@@ -863,7 +863,6 @@ void Slur::layout()
             // tick and tick2 has no meaning so no layout is
             // possible and needed
             //
-            setLen(_spatium * 7);
             SlurSegment* s;
             if (segments.isEmpty()) {
                   s = new SlurSegment(score());
