@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: staff.cpp 3769 2010-12-15 18:28:07Z lasconic $
+//  $Id: staff.cpp 4541 2011-07-17 16:52:22Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -399,6 +399,10 @@ void Staff::changeClef(int tick, int st)
                         break;
                         }
                   if (!e->generated()) {
+                        if (etick != tick) {
+                              oval = _clefList->clef(etick);
+                              _score->undoChangeClef(this, etick, oval, NO_CLEF);
+                              }
                         _score->undoRemoveElement(e);
                         m->cmdRemoveEmptySegment(segment);
                         }
