@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: style.cpp 4532 2011-07-16 11:13:18Z lasconic $
+//  $Id: style.cpp 5195 2012-01-06 16:58:35Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -295,7 +295,7 @@ const TextStyle defaultTextStyleArray[] = {
       TextStyle(QT_TRANSLATE_NOOP("MuseScore", "Volta"), ff, 11, true, false, false,
          ALIGN_LEFT, 0.5, .0, OS, 0, 0, true),
 
-      TextStyle(QT_TRANSLATE_NOOP("MuseScore", "Frame"), ff, 11, true, false, false,
+      TextStyle(QT_TRANSLATE_NOOP("MuseScore", "Frame"), ff, 11, false, false, false,
          ALIGN_LEFT, 0, 0, OS, 0, 0, true),
 
       TextStyle(QT_TRANSLATE_NOOP("MuseScore", "TextLine"), ff,  12, false, false, false,
