@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: system.cpp 3758 2010-12-13 14:52:53Z wschweer $
+//  $Id: system.cpp 4377 2011-06-13 10:14:50Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -61,10 +61,10 @@ SysStaff::SysStaff()
 
 SysStaff::~SysStaff()
       {
-      foreach(Bracket* b, brackets)
-            delete b;
+      /*foreach(Bracket* b, brackets)
+            delete b;*/
       brackets.clear();
-      delete instrumentName;
+      //delete instrumentName;
       instrumentName = 0;
       }
 
@@ -238,6 +238,8 @@ void System::layout(double xo1)
       if ((nstaves > 1 && score()->styleB(ST_startBarlineMultiple)) || (nstaves <= 1 && score()->styleB(ST_startBarlineSingle))) {
             if(barLine == 0){
               barLine = new Line(score(), true);
+              barLine->setSelectable(false);
+              barLine->setGenerated(true);
               barLine->setLineWidth(score()->styleS(ST_barWidth));
               barLine->setParent(this);
               }
@@ -481,7 +483,7 @@ void System::setInstrumentName(int staffIdx)
       if (!iname) {
             Part* part = s->part();
             iname = new TextC(_firstSystem ? (*part->longName()) : (*part->shortName()));
-            iname->setSelectable(false);
+            iname->setMovable(false);
             staff->instrumentName = iname;
             }
       else {
