@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: text.cpp 4362 2011-06-11 13:04:43Z lasconic $
+//  $Id: text.cpp 5430 2012-03-07 18:07:26Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -1017,7 +1017,7 @@ bool TextB::edit(ScoreView* view, int /*grip*/, int key, Qt::KeyboardModifiers m
                         break;
                   }
 #ifndef Q_WS_MAC
-            if (key != Qt::Key_Space && key != Qt::Key_Minus)
+            if (key != Qt::Key_Space && key != Qt::Key_Minus && key != Qt::Key_Right && key != Qt::Key_Left)
                   return true;
 #endif
             }
@@ -1222,7 +1222,7 @@ qreal TextB::baseLine() const
 
 double TextB::lineSpacing() const
       {
-      return QFontMetricsF(doc()->defaultFont(), pdev).lineSpacing();
+      return QFontMetricsF(doc()->defaultFont()).lineSpacing();
       }
 
 //---------------------------------------------------------
@@ -1232,7 +1232,7 @@ double TextB::lineSpacing() const
 
 double TextB::lineHeight() const
       {
-      QFontMetricsF fm(doc()->defaultFont(), pdev);
+      QFontMetricsF fm(doc()->defaultFont());
       return fm.height();
       }
 
