@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: tuplet.cpp 4136 2011-03-30 19:54:49Z lasconic $
+//  $Id: tuplet.cpp 5349 2012-02-20 22:00:05Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -157,11 +157,26 @@ void Tuplet::layout()
       //
       //   shall we draw a bracket?
       //
-      if (cr1->beam() && !tupletContainsRest) {
-            if (_bracketType == AUTO_BRACKET)
-                  _hasBracket = false;
-            else
-                  _hasBracket = _bracketType == SHOW_BRACKET;
+      if (_bracketType == AUTO_BRACKET) {
+            _hasBracket = tupletContainsRest;
+            if (!_hasBracket) {
+                  foreach(DurationElement* e, _elements) {
+                        if (e->type() == TUPLET) {
+                              _hasBracket = true;
+                              break;
+                              }
+                        else if (e->isChordRest()) {
+                              ChordRest* cr = static_cast<ChordRest*>(e);
+                              //
+                              // maybe we should check for more than one beam
+                              //
+                              if (cr->beam() == 0) {
+                                    _hasBracket = true;
+                                    break;
+                                    }
+                              }
+                        }
+                  }
             }
       else
             _hasBracket = _bracketType != SHOW_NO_BRACKET;
@@ -414,7 +429,7 @@ void Tuplet::write(Xml& xml) const
 //   read
 //---------------------------------------------------------
 
-void Tuplet::read(QDomElement e, const QList<Tuplet*>& tuplets)
+void Tuplet::read(QDomElement e, QList<Tuplet*>& tuplets, Measure* measure)
       {
       int bl = -1;
       _id    = e.attribute("id", "0").toInt();
