@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: undo.cpp 4366 2011-06-11 17:51:10Z lasconic $
+//  $Id: undo.cpp 5372 2012-02-24 16:47:30Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -195,7 +195,8 @@ void UndoStack::push(UndoCommand* cmd)
 
 void UndoStack::setClean()
       {
-      if (cleanIdx != curIdx) {
+      // freshly created parts are dirty, but have no undo actions
+      if (cleanIdx != curIdx || (cleanIdx==0 && curIdx==0)) {
             cleanIdx = curIdx;
             emit cleanChanged(true);
             }
