@@ -1,7 +1,7 @@
 //=============================================================================
 //  MusE Score
 //  Linux Music Score Editor
-//  $Id: undo.h 2796 2010-02-28 11:17:50Z wschweer $
+//  $Id: undo.h 3832 2011-01-04 12:13:26Z lasconic $
 //
 //  Copyright (C) 2002-2009 Werner Schweer and others
 //
@@ -297,13 +297,12 @@ class RemoveStaves : public UndoCommand {
 class SortStaves : public UndoCommand {
       Score* score;
       QList<int> list;
-
-      void flip();
+      QList<int> rlist;
 
    public:
       SortStaves(Score*, QList<int>);
-      virtual void undo() { flip(); }
-      virtual void redo() { flip(); }
+      virtual void undo();
+      virtual void redo();
       };
 
 //---------------------------------------------------------
@@ -425,6 +424,24 @@ class FlipBeamDirection : public UndoCommand {
       virtual void redo() { flip(); }
       };
 
+//---------------------------------------------------------
+//   ChangeKeySig
+//---------------------------------------------------------
+
+class ChangeKeySig : public UndoCommand {
+	  KeySig* keysig;
+	  KeySigEvent ks;
+	  bool showCourtesy;
+	  bool showNaturals;
+
+	  void flip();
+
+   public:
+	  ChangeKeySig(KeySig*, KeySigEvent newKeySig, bool sc, bool sn);
+	  virtual void undo() { flip(); }
+	  virtual void redo() { flip(); }
+	  };
+
 //---------------------------------------------------------
 //   FlipTupletDirection
 //---------------------------------------------------------
@@ -455,22 +472,6 @@ class ChangeKey : public UndoCommand {
       virtual void redo();
       };
 
-//---------------------------------------------------------
-//   ChangeKeySig
-//---------------------------------------------------------
-
-class ChangeKeySig : public UndoCommand {
-      KeySig* keysig;
-      KeySigEvent ks;
-
-      void flip();
-
-   public:
-      ChangeKeySig(KeySig*, KeySigEvent newKeySig);
-      virtual void undo() { flip(); }
-      virtual void redo() { flip(); }
-      };
-
 //---------------------------------------------------------
 //   ChangeClef
 //---------------------------------------------------------
