@@ -1,7 +1,7 @@
 //=============================================================================
 //  MuseScore
 //  Linux Music Score Editor
-//  $Id: utils.cpp 4302 2011-05-20 08:27:38Z lasconic $
+//  $Id: utils.cpp 5407 2012-03-03 14:17:18Z lasconic $
 //
 //  Copyright (C) 2002-2007 Werner Schweer and others
 //
@@ -371,7 +371,7 @@ double curTime()
 void selectNoteMessage()
       {
       QMessageBox::information(0,
-         QMessageBox::tr("MuseScore:"),
+         "MuseScore",
          QMessageBox::tr("No note selected:\n"
                          "Please select a single note and retry operation\n"),
          QMessageBox::Ok, QMessageBox::NoButton);
@@ -380,7 +380,7 @@ void selectNoteMessage()
 void selectNoteRestMessage()
       {
       QMessageBox::information(0,
-         QMessageBox::tr("MuseScore:"),
+         "MuseScore",
          QMessageBox::tr("No note or rest selected:\n"
                          "Please select a single note or rest and retry operation\n"),
          QMessageBox::Ok, QMessageBox::NoButton);
@@ -389,7 +389,7 @@ void selectNoteRestMessage()
 void selectNoteSlurMessage()
       {
       QMessageBox::information(0,
-         QMessageBox::tr("MuseScore:"),
+         "MuseScore",
          QMessageBox::tr("Please select a single note or slur and retry operation\n"),
          QMessageBox::Ok, QMessageBox::NoButton);
       }
@@ -397,16 +397,16 @@ void selectNoteSlurMessage()
 void selectStavesMessage()
       {
       QMessageBox::information(0,
-         QMessageBox::tr("MuseScore:"),
+         "MuseScore",
          QMessageBox::tr("Please select one or more staves and retry operation\n"),
          QMessageBox::Ok, QMessageBox::NoButton);
       }
 
 static const char* vall[] = {
-            "c","c#","d","d#","e","f","f#","g","g#","a","a#","h"
+            "c","c#","d","d#","e","f","f#","g","g#","a","a#","b"
             };
 static const char* valu[] = {
-            "C","C#","D","D#","E","F","F#","G","G#","A","A#","H"
+            "C","C#","D","D#","E","F","F#","G","G#","A","A#","B"
             };
 
 /*!
@@ -611,7 +611,7 @@ int transposeTpc(int tpc, Interval interval, bool useDoubleSharpsFlats)
             // alter  = p1 + semitones - pitch;
 	          if (alter < 0) {
 	                alter *= -1;
-	                alter = 12 - alter;
+	                alter = 1200 - alter;
 	                }
             alter %= 12;
 	          if (alter > 6)
