@@ -26,9 +26,25 @@
 
 class MuseScore;
 
+//---------------------------------------------------------
+//   MyNetworkAccessManager
+//---------------------------------------------------------
+
+class MyNetworkAccessManager: public QNetworkAccessManager 
+      {
+      Q_OBJECT
+      
+   public:  
+      MyNetworkAccessManager(QObject *parent) : QNetworkAccessManager(parent) {}
+      
+   protected:
+      QNetworkReply * createRequest(Operation op,
+                                          const QNetworkRequest & req,
+                                          QIODevice * outgoingData = 0);
+      };
+
 // Derive from QWebPage, because a WebPage handles
 // plugin creation
-
 //---------------------------------------------------------
 //   MyWebPage
 //---------------------------------------------------------
@@ -43,7 +59,6 @@ class MyWebPage: public QWebPage
          const QUrl &url,
          const QStringList &paramNames,
          const QStringList & paramValues);
-      QString userAgentForUrl(const QUrl &url) const;
 
    public:
       MyWebPage(QObject *parent = 0);
@@ -79,7 +94,6 @@ class MyWebView: public QWebView
       ~MyWebView();
       MyWebPage* webPage() {return &m_page;}
       virtual QSize	sizeHint () const;
-      void load (const QNetworkRequest & request, QNetworkAccessManager::Operation operation = QNetworkAccessManager::GetOperation, const QByteArray & body = QByteArray() );
       };
 
 //---------------------------------------------------------
