@@ -5,7 +5,7 @@
 //
 //  Test plugin
 //
-//  Copyright (C)2008 Werner Schweer and others
+//  Copyright (C)2008-2012 Werner Schweer and others
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License version 2.
@@ -773,7 +773,7 @@ function binb2b64(binarray)
 function init()
       {
       // print("test script init");
-      var action = new QAction(new QIcon(pluginPath+"/icons/filesaveonline.svg"), "Save Online...", mscore);
+      var action = new QAction(new QIcon(pluginPath+"/icons/filesaveonline.svg"), qsTr("Save Online..."), mscore);
       var menu = mscore.fileMenu();
       var actionList = menu.actions();
       menu.insertAction(actionList[7], action);
@@ -1045,6 +1045,8 @@ var username;
 
 function run()
   {  
+    if (typeof curScore === 'undefined')
+          return;
     loadPreferences();
     if(loadSettings()){
       getUser();
@@ -1111,7 +1113,7 @@ function processAnswerRequestToken(id ,error){
         form.show();  
     }else{
          //message error
-        QMessageBox.critical(0, "Error", "Cannot get request token [" + http.errorString() + "]" );
+        QMessageBox.critical(0, qsTr("Error"), qsTr("Cannot get request token [%1]").arg(http.errorString()));
     }
   }
 }
@@ -1133,6 +1135,7 @@ function launchBrowser() {
         var file   = new QFile(pluginPath + "/ui/authorize_dialog.ui");
         file.open(QIODevice.OpenMode(QIODevice.ReadOnly, QIODevice.Text));
         form = loader.load(file, null);
+        form.setWindowFlags(Qt.WindowSystemMenuHint);
         form.lineEditUrl.text = url;
         form.lineEditUrl.cursorPosition = 0;
         form.buttonBox.accepted.connect(acceptAuthorize);
@@ -1201,7 +1204,7 @@ function processAnswerAccessToken(id ,error){
         getUser();
     }else{
         //message error
-        QMessageBox.critical(0, "Error", "Cannot get access token [" + http.errorString()+ "]");
+        QMessageBox.critical(0, qsTr("Error"), qsTr("Cannot get access token [%1]").arg(http.errorString()));
     }      
   }
 }
@@ -1212,21 +1215,21 @@ function formBeforeUpload(){
       file.open(QIODevice.OpenMode(QIODevice.ReadOnly, QIODevice.Text));
       form = loader.load(file, null);
       form.setWindowFlags(Qt.WindowSystemMenuHint); //remove the what's this button
-      form.verticalLayoutWidget.title.text = curScore.title;
-      form.verticalLayoutWidget.license.addItem("All Rights reserved", "all-rights-reserved");
-      form.verticalLayoutWidget.license.addItem("Creative Commons Attribution", "cc-by");
-	    form.verticalLayoutWidget.license.addItem("Creative Commons Attribution Share Alike", "cc-by-sa");
-      form.verticalLayoutWidget.license.addItem("Creative Commons Attribution No Derivative Works", "cc-by-nd");
-      form.verticalLayoutWidget.license.addItem("Creative Commons Attribution Noncommercial", "cc-by-nc");
-      form.verticalLayoutWidget.license.addItem("Creative Commons Attribution Noncommercial Share Alike", "cc-by-nc-sa");
-	    form.verticalLayoutWidget.license.addItem("Creative Commons Attribution Noncommercial Non Derivate Works", "cc-by-nc-nd");
-      form.verticalLayoutWidget.license.addItem("Public Domain", "publicdomain");
-      form.verticalLayoutWidget.license.addItem("Creative Commons Zero", "cc-zero");
-      form.horizontalLayoutWidget.lblUsername.text = username;
+      form.title.text = curScore.title;
+      form.license.addItem(qsTr("All Rights reserved"), "all-rights-reserved");
+      form.license.addItem(qsTr("Creative Commons Attribution"), "cc-by");
+	    form.license.addItem(qsTr("Creative Commons Attribution Share Alike"), "cc-by-sa");
+      form.license.addItem(qsTr("Creative Commons Attribution No Derivative Works"), "cc-by-nd");
+      form.license.addItem(qsTr("Creative Commons Attribution Noncommercial"), "cc-by-nc");
+      form.license.addItem(qsTr("Creative Commons Attribution Noncommercial Share Alike"), "cc-by-nc-sa");
+	    form.license.addItem(qsTr("Creative Commons Attribution Noncommercial Non Derivate Works"), "cc-by-nc-nd");
+      form.license.addItem(qsTr("Public Domain"), "publicdomain");
+      form.license.addItem(qsTr("Creative Commons Zero"), "cc-zero");
+      form.lblUsername.text = username;
       form.buttonBox.accepted.connect(saveAndUpload);
-      form.horizontalLayoutWidget.btnSignout.pressed.connect(signout);
-      form.horizontalLayoutWidget.chkSignoutOnExit.checked = (preferences.signoutOnExit == 'true');
-      form.horizontalLayoutWidget.chkSignoutOnExit.stateChanged.connect(signoutOnExit);
+      form.btnSignout.pressed.connect(signout);
+      form.chkSignoutOnExit.checked = (preferences.signoutOnExit == 'true');
+      form.chkSignoutOnExit.stateChanged.connect(signoutOnExit);
       form.show();  
 }
 
@@ -1252,11 +1255,11 @@ function saveAndUpload(){
   var path = QDir.tempPath() + "/temp.mscz";
   if(curScore.save(path, "mscz")){
 
-      var description = form.verticalLayoutWidget.description.plainText;
-      var title = form.verticalLayoutWidget.title.text;
-      var tags = form.verticalLayoutWidget.tags.text;
-      var priv = (form.verticalLayoutWidget.rbPrivate.checked?1:0);
-      var licenseCmb = form.verticalLayoutWidget.license;
+      var description = form.description.plainText;
+      var title = form.title.text;
+      var tags = form.tags.text;
+      var priv = (form.rbPrivate.checked?1:0);
+      var licenseCmb = form.license;
       var license = licenseCmb.itemData(licenseCmb.currentIndex);
       
       var accessor = { consumerSecret: consumer.consumerSecret 
@@ -1376,12 +1379,14 @@ function processAnswerUpload(id ,error){
          if(array['base'])
             base = array['base'];
          
-         if (array["score_id"])
-            QMessageBox.about(0, "Success", "<a href=\""+base+"/my_scores\">Finished! Go to my scores.</a>"); 
+         if (array["score_id"]) {
+            curScore.source = array["permalink"]; //store source for next time
+            QMessageBox.about(0, qsTr("Success"), qsTr('Finished! <a href="%1\">Go to my score.</a>').arg(array["permalink"]));
+            } 
       } 
      }else{
         //message error
-        QMessageBox.critical(0, "Error", "Cannot upload [" + http.errorString()+ "]");
+        QMessageBox.critical(0, qsTr("Error"), qsTr("Cannot upload [%1]").arg(http.errorString()));
      }
   }
 }
@@ -1527,10 +1532,10 @@ function saveSettings(){
         settingsFile.flush();
         settingsFile.close();
       }else{
-        QMessageBox.critical(0, "Error", "Cannot write settings.");
+        QMessageBox.critical(0, qsTr("Error"), qsTr("Cannot write settings."));
       }
     }else{
-      QMessageBox.critical(0, "Error", "Cannot create settings directory.");
+      QMessageBox.critical(0, qsTr("Error"), qsTr("Cannot create settings directory."));
     }
 }
 
@@ -1573,10 +1578,10 @@ function savePreferences(){
         preferencesFile.flush();
         preferencesFile.close();
       }else{
-        QMessageBox.critical(0, "Error", "Cannot write preferences.");
+        QMessageBox.critical(0, qsTr("Error"), qsTr("Cannot write preferences."));
       }
     }else{
-      QMessageBox.critical(0, "Error", "Cannot create preferences directory.");
+      QMessageBox.critical(0, qsTr("Error"), qsTr("Cannot create preferences directory."));
     }
 }
 
